@@ -23,10 +23,18 @@
 
 package ch.kuramo.javie.api;
 
+/**
+ * <p>{@link IArray} のオブジェクト配列版です。
+ * {@link ch.kuramo.javie.api.services.IArrayPools#getObjectArray(int)} から返されます。</p>
+ * 
+ * <p>型パラメータ<code>T</code>により<code>IObjectArray&lt;T&gt;</code>オブジェクト自体の型安全性は保証されますが、
+ * {@link #getArray()} から返される生の配列は<code>Object[]</code>なので
+ * 配列の要素を使用する際は適切にキャストする必要があります。</p>
+ *
+ * @param <T> オブジェクト配列の要素の型
+ * 
+ * @see ch.kuramo.javie.api.services.IArrayPools#getObjectArray(int)
+ */
 public interface IObjectArray<T> extends IArray<Object[]> {
 
-	T get(int i);
-
-	void set(int i, T value);
-
 }
