@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -200,7 +200,13 @@ public interface IVideoBuffer {
 		 * テクスチャが繰り返されます。
 		 * @since 0.5.0
 		 */
-		REPEAT
+		REPEAT,
+
+		/**
+		 * テクスチャが鏡面型で繰り返されます。
+		 * @since 0.5.1
+		 */
+		MIRRORED_REPEAT
 
 	}
 
