@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -60,9 +60,20 @@ public class Initializer {
 
 	public static void initialize() {
 		Initializer initializer = InjectorHolder.getInjector().getInstance(Initializer.class);
+
+		SplashProgressMonitor.subTask("Scanning Core Classes");
 		initializer.scanCoreClasses();
+		SplashProgressMonitor.worked(1);
+
+		SplashProgressMonitor.subTask("Scanning Extensions");
 		initializer.scanExtensions();
+		SplashProgressMonitor.worked(1);
+
+		SplashProgressMonitor.subTask("Scanning EzPlugins");
 		initializer.scanEasyPlugins();
+		SplashProgressMonitor.worked(1);
+
+		SplashProgressMonitor.subTask("");
 	}
 
 
@@ -116,6 +127,7 @@ public class Initializer {
 				String id = ext.getUniqueIdentifier();
 				String name = ext.getLabel();
 				_logger.info(String.format("loading JaviePlugin: %s [%s]", name, id));
+				SplashProgressMonitor.subTask("Scanning Extension: " + name);
 
 				JaviePlugin plugin;
 				try {
@@ -203,6 +215,7 @@ public class Initializer {
 				name = name.substring(lastSlash+1);
 			}
 			_logger.info(String.format("loading ezplugin: %s", name));
+			SplashProgressMonitor.subTask("Scanning EzPlugin: " + name);
 
 			try {
 				AnnotationDB db = new AnnotationDB();
