@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -33,7 +33,6 @@ import org.eclipse.swt.events.ModifyEvent;
 import org.eclipse.swt.events.ModifyListener;
 import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.events.SelectionListener;
-import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.widgets.Button;
 import org.eclipse.swt.widgets.Combo;
 import org.eclipse.swt.widgets.Composite;
@@ -122,10 +121,6 @@ public class NewImageSequenceAction extends Action {
 		Dialog dialog = new Dialog(window.getShell()) {
 			private Combo fpsCombo;
 
-			protected Point getInitialSize() {
-				return new Point(300, 120);
-			}
-
 			protected void configureShell(Shell newShell) {
 				super.configureShell(newShell);
 				newShell.setText("イメージシーケンスの読み込み");
@@ -134,13 +129,13 @@ public class NewImageSequenceAction extends Action {
 			protected Control createDialogArea(Composite parent) {
 				Composite composite = (Composite) super.createDialogArea(parent);
 
-				GridBuilder gb = new GridBuilder(composite, 16, true);
+				GridBuilder gb = new GridBuilder(composite, 3, false);
 
-							gb.hSpan(4).hAlign(SWT.RIGHT).hGrab().label(SWT.NULL, "フレームレート:");
-				fpsCombo =	gb.hSpan(3).hAlign(SWT.FILL).hGrab().combo(SWT.NULL, 0,
+							gb.hSpan(1).hAlign(SWT.RIGHT).label(SWT.NULL, "フレームレート:");
+				fpsCombo =	gb.hSpan(1).hAlign(SWT.FILL).combo(SWT.NULL, 0,
 									FrameRateComboUtil.getComboItems(),
 									FrameRateComboUtil.toComboItem(FrameDuration.FPS_29_97));
-							gb.hSpan(9).hGrab().label(SWT.NULL, "フレーム／秒");
+							gb.hSpan(1).label(SWT.NULL, "フレーム／秒");
 
 				fpsCombo.addModifyListener(new ModifyListener() {
 					public void modifyText(ModifyEvent e) { updateOkButton(); }
@@ -153,6 +148,7 @@ public class NewImageSequenceAction extends Action {
 				Composite grid = gb.getComposite();
 				grid.setTabList(gb.getTabList());
 
+				parent.pack();
 				return composite;
 			}
 
