@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,10 +23,6 @@
 
 package ch.kuramo.javie.app.actions;
 
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
-
 import org.eclipse.jface.wizard.Wizard;
 
 import ch.kuramo.javie.app.CommandIds;
@@ -45,6 +41,11 @@ public class QTMovieOutputAction extends AbstractOutputAction<MacOSXQTMovieOutpu
 		//setImageDescriptor(Activator.getImageDescriptor("/icons/qtmovie_output.png"));
 	}
 
+	@Override
+	protected String getDefaultExtension() {
+		return ".mov";
+	}
+
 	@Override
 	protected MacOSXQTMovieOutput createOutput(Injector injector) {
 		return injector.getInstance(MacOSXQTMovieOutput.class);
@@ -55,25 +56,4 @@ public class QTMovieOutputAction extends AbstractOutputAction<MacOSXQTMovieOutpu
 		return new QTMovieOutputWizard(getComposition(), output);
 	}
 
-	@Override
-	protected String getDefaultExtension() {
-		return ".mov";
-	}
-
-	@Override
-	protected String[] getSaveDialogFilters() {
-		List<String> filters = new ArrayList<String>(Arrays.asList("QuickTime ムービー", "*.mov"));
-		filters.addAll(Arrays.asList(super.getSaveDialogFilters()));
-		return filters.toArray(new String[filters.size()]);
-	}
-
-	public static boolean isAvailable() {
-		try {
-			Class.forName(MacOSXQTMovieOutput.class.getName());
-			return true;
-		} catch (Throwable t) {
-			return false;
-		}
-	}
-
 }
