@@ -74,7 +74,7 @@ public class PlayerMuteAction extends Action implements IMenuCreator {
 		menu = new Menu(parent);
 
 
-		Action action = new Action("スクラブ中にオーディオを再生する", IAction.AS_RADIO_BUTTON) {
+		Action action = new Action("スクラブ中にオーディオを再生する", IAction.AS_CHECK_BOX) {
 			{
 				setChecked(mediaPlayer.isAudioScrubEnabled());
 			}
