@@ -87,7 +87,7 @@ public class ModifyLayerKeyframesOperation<V> extends ProjectOperation {
 		if (oldKeyframe != null) {
 			return oldKeyframe.interpolation;
 		} else {
-			SortedMap<Time, Keyframe<V>> head = avalue.headKeyframeMap(time);
+			SortedMap<Time, Keyframe<V>> head = avalue.getKeyframeMap().headMap(time);
 			if (!head.isEmpty()) {
 				return head.get(head.lastKey()).interpolation;
 			} else {
