@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -114,7 +114,7 @@ public class ReverseLayerTimeOperation extends ProjectOperation {
 
 			_layers.add(new LayerEntry(layer.getId(), layer.getStartTime(), layer.getRate()));
 
-			for (String property : PropertyUtil.getPropertyNames(layer)) {
+			for (String property : PropertyUtil.getLayerPropertyNames(layer)) {
 				Object o = PropertyUtil.getProperty(layer, property);
 				if (o instanceof AnimatableValue<?>) {
 					AnimatableValue<?> avalue = (AnimatableValue<?>) o;
@@ -244,17 +244,25 @@ public class ReverseLayerTimeOperation extends ProjectOperation {
 		for (LayerEntry e : _layers) {
 			Layer layer = comp.getLayer(e.layerId);
 
+			Time newStartTime = null;
+			Time oldStartTime = layer.getStartTime();
+			Time inPoint = layer.getInPoint();
+			Time outPoint = layer.getOutPoint();
+
 			if (layer instanceof MediaLayer) {
 				MediaInput mi = ((MediaLayer) layer).getMediaInput();
 				Time duration = mi.getDuration();
 				if (duration != null) {
-					Time startTime = layer.getStartTime();
-					Time inPoint = layer.getInPoint();
-					Time outPoint = layer.getOutPoint();
-					layer.setStartTime(inPoint.subtract(startTime.add(duration).subtract(outPoint)));
+					Time endTime = oldStartTime.add(
+							new Time((long)(duration.timeValue/Math.abs(e.rate)), duration.timeScale));
+					newStartTime = inPoint.subtract(endTime.subtract(outPoint));
 				}
 			}
+			if (newStartTime == null) {
+				newStartTime = outPoint.add(inPoint.subtract(oldStartTime));
+			}
 
+			layer.setStartTime(newStartTime);
 			layer.setRate(-e.rate);
 			layers.add(layer);
 		}
