@@ -82,9 +82,9 @@ public class AngleElementDelegate extends AnimatableValueElementDelegate<Double>
 			return;
 		}
 
-		x = drawValue(gc, x, y, height, focused, (int)(value/360), "x");
+		x = drawValue(gc, x, y, height, focused, (int)(valueToDraw/360), "x");
 		x += 5;
-		x = drawValue(gc, x, y, height, focused, value%360, true, displayPrecision, unit);
+		x = drawValue(gc, x, y, height, focused, valueToDraw%360, true, displayPrecision, unit);
 	}
 
 	protected int drawValue(GC gc, int x, int y, int height, int valueIndex, double value) {
@@ -118,6 +118,10 @@ public class AngleElementDelegate extends AnimatableValueElementDelegate<Double>
 		return originalValue + increment * dx * (valueIndex == 0 ? 360 : 1);
 	}
 
+	protected boolean isInPlaceEditorActive() {
+		return (editor != null);
+	}
+
 	public boolean canEdit(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
 			return canInPlaceEdit;
@@ -137,7 +141,8 @@ public class AngleElementDelegate extends AnimatableValueElementDelegate<Double>
 
 	public Object getCellEditorValue(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
-			return (valueIndex == 0) ? String.valueOf((int)(value/360)) : formatValue(value%360, editorPrecision);
+			return (valueIndex == 0) ? String.valueOf((int)(valueWithoutExpr/360))
+									 : formatValue(valueWithoutExpr%360, editorPrecision);
 		}
 		return null;
 	}
@@ -147,16 +152,16 @@ public class AngleElementDelegate extends AnimatableValueElementDelegate<Double>
 			try {
 				double newValue;
 				if (valueIndex == 0) {
-					if (value.equals(String.valueOf((int)(this.value/360)))) {
+					if (value.equals(String.valueOf((int)(valueWithoutExpr/360)))) {
 						return;
 					}
-					newValue = Double.valueOf((String)value)*360 + (this.value%360);
+					newValue = Double.valueOf((String)value)*360 + (valueWithoutExpr%360);
 	
 				} else /*if (valueIndex == 1)*/ {
-					if (value.equals(formatValue(this.value%360, editorPrecision))) {
+					if (value.equals(formatValue(valueWithoutExpr%360, editorPrecision))) {
 						return;
 					}
-					newValue = (int)(this.value/360)*360 + Double.valueOf((String)value);
+					newValue = (int)(valueWithoutExpr/360)*360 + Double.valueOf((String)value);
 				}
 				modifyValue(newValue);
 			} catch (NumberFormatException e) {
@@ -218,9 +223,9 @@ public class AngleElementDelegate extends AnimatableValueElementDelegate<Double>
 					int x = WIN32 ? 5 : 2;
 					int height = composite.getBounds().height;
 
-					x = drawValue(gc, x, 0, height, 0, value);
+					x = drawValue(gc, x, 0, height, 0, valueWithoutExpr);
 					x += 5;
-					x = drawValue(gc, x, 0, height, 1, value);
+					x = drawValue(gc, x, 0, height, 1, valueWithoutExpr);
 				}
 			});
 
