@@ -72,7 +72,7 @@ public class AnimatableIntegerElementDelegate extends AnimatableValueElementDele
 
 	protected void drawValue(GC gc, int x, int y, int height, boolean focused) {
 		if (editor == null) {
-			drawValue(gc, x, y, height, focused, value, unit);
+			drawValue(gc, x, y, height, focused, valueToDraw, unit);
 		}
 	}
 
@@ -84,6 +84,10 @@ public class AnimatableIntegerElementDelegate extends AnimatableValueElementDele
 		return originalValue + (int)(increment * dx);
 	}
 
+	protected boolean isInPlaceEditorActive() {
+		return (editor != null);
+	}
+
 	public boolean canEdit(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
 			return canInPlaceEdit;
@@ -103,7 +107,7 @@ public class AnimatableIntegerElementDelegate extends AnimatableValueElementDele
 
 	public Object getCellEditorValue(int columnIndex) {
 		if (columnIndex == LayerCompositionView.VALUE_COL) {
-			return value.toString();
+			return valueWithoutExpr.toString();
 		}
 		return null;
 	}
