@@ -61,7 +61,7 @@ class TextLeadingElementDelegate extends AnimatableDoubleElementDelegate {
 	}
 
 	protected void drawValue(GC gc, int x, int y, int height, boolean focused) {
-		if (value < 0) {
+		if (valueToDraw < 0) {
 			drawValue(gc, x, y, height, focused, AUTO);
 		} else {
 			super.drawValue(gc, x, y, height, focused);
@@ -69,14 +69,14 @@ class TextLeadingElementDelegate extends AnimatableDoubleElementDelegate {
 	}
 
 	protected Double dragGesture(double dx, double dy) {
-		if (value < 0 && originalValue < 0) {
+		if (valueWithoutExpr < 0 && originalValue < 0) {
 			originalValue = autoValue();
 		}
 		return Math.max(0, super.dragGesture(dx, dy));
 	}
 
 	public Object getCellEditorValue(int columnIndex) {
-		if (columnIndex == LayerCompositionView.VALUE_COL && value < 0) {
+		if (columnIndex == LayerCompositionView.VALUE_COL && valueWithoutExpr < 0) {
 			return autoValueAsCellEditorValue();
 		} else {
 			return super.getCellEditorValue(columnIndex);
@@ -89,7 +89,7 @@ class TextLeadingElementDelegate extends AnimatableDoubleElementDelegate {
 			try {
 				if (value.equals(autoValueAsCellEditorValue())
 						|| value.equals(AUTO) || Double.valueOf((String) value) < 0) {
-					if (this.value >= 0) {
+					if (valueWithoutExpr >= 0) {
 						super.setCellEditorValue(columnIndex, "-1");
 					}
 				} else {
