@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,8 +23,10 @@
 
 package ch.kuramo.javie.core;
 
-public interface ItemLayer extends Layer {
+public interface ItemLayer<T extends Item> extends Layer {
 
-	Item getItem();
+	T getItem();
+
+	void setItem(T item);
 
 }
