@@ -23,6 +23,8 @@
 
 package ch.kuramo.javie.core;
 
+import java.util.List;
+
 public interface MediaItemLayer extends MediaLayer, ItemLayer<MediaItem> {
 
 	boolean isCTCR();
@@ -35,4 +37,6 @@ public interface MediaItemLayer extends MediaLayer, ItemLayer<MediaItem> {
 
 	boolean isPrecompositionLayer();
 
+	List<VideoLayerRenderer> createCollapsedRenderers();
+
 }
