@@ -23,10 +23,6 @@
 
 package ch.kuramo.javie.core;
 
-import java.util.Locale;
-import java.util.MissingResourceException;
-import java.util.ResourceBundle;
-
 public enum TrackMatte {
 
 	NONE,
@@ -35,21 +31,4 @@ public enum TrackMatte {
 	LUMA,
 	LUMA_INVERTED;
 
-
-	private final String label = getLabel();
-
-	private String getLabel() {
-		try {
-			String bundleName = TrackMatte.class.getPackage().getName() + ".messages";
-			ResourceBundle bundle = ResourceBundle.getBundle(bundleName, Locale.getDefault());
-			return bundle.getString(String.format("%s.%s", TrackMatte.class.getSimpleName(), name()));
-		} catch (MissingResourceException e) {
-			return name();
-		}
-	}
-
-	public String label() {
-		return label;
-	}
-
 }
