@@ -550,6 +550,14 @@ public class LayerCompositionImpl extends AbstractComposition implements LayerCo
 			return getSize().height;
 		}
 
+		public double getFrameDuration() {
+			return LayerCompositionImpl.this.getFrameDuration().toSecond();
+		}
+
+		public double getDuration() {
+			return LayerCompositionImpl.this.getDuration().toSecond();
+		}
+
 	}
 
 }
