@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009,2010 Yoshikazu Kuramochi
+ * Copyright (c) 2009-2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -190,6 +190,10 @@ public class MacOSXQTCoreVideoSource implements MediaSource {
 					gl.glDeleteBuffers(1, new int[] { _fboId }, 0);
 					_fboId = 0;
 
+					// MacOSX 10.6.x(10.6.0では発生しなかった) では、glFinishしないと
+					// このあとの glContext.release() で画面が一瞬明滅し、その後しばらく停止してしまうことがある。
+					gl.glFinish();
+
 					ReentrantLock lock = _glGlobal.getGlobalLock();
 					lock.lock();
 					try {
