@@ -225,7 +225,11 @@ public class VideoBufferImpl implements IVideoBuffer {
 					if (min[0] != GL2.GL_LINEAR_MIPMAP_LINEAR) {
 						gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_LINEAR_MIPMAP_LINEAR);
 						gl.glTexParameterf(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MAX_ANISOTROPY_EXT, 16.0f);
-						gl.glGenerateMipmap(GL2.GL_TEXTURE_2D);
+						if (glGlobal.isWindows() && glGlobal.isRadeonHD5k6k()) {
+							generateMipmap(gl, texture);
+						} else {
+							gl.glGenerateMipmap(GL2.GL_TEXTURE_2D);
+						}
 					}
 					break;
 
@@ -543,4 +547,92 @@ public class VideoBufferImpl implements IVideoBuffer {
 		}
 	}
 
+	private void generateMipmap(GL2 gl, int texture) {
+		// 呼び出し側で既にバインド済み
+		//gl.glBindTexture(GL2.GL_TEXTURE_2D, texture);
+
+		int[] size = new int[2];
+		gl.glGetTexLevelParameteriv(GL2.GL_TEXTURE_2D, 0, GL2.GL_TEXTURE_WIDTH, size, 0);
+		gl.glGetTexLevelParameteriv(GL2.GL_TEXTURE_2D, 0, GL2.GL_TEXTURE_HEIGHT, size, 1);
+
+		for (int level = 1; size[0] > 1 || size[1] > 1; ++level) {
+			size[0] = Math.max(size[0]/2, 1);
+			size[1] = Math.max(size[1]/2, 1);
+			gl.glTexImage2D(GL2.GL_TEXTURE_2D, level, colorMode.glInternalFormat,
+					size[0], size[1], 0, GL2.GL_BGRA, colorMode.glDataType, null);
+		}
+
+		IVideoBuffer buffer0 = this;
+		try {
+			for (int level = 1; ; ++level) {
+				IVideoBuffer buffer1 = null;
+				gl.glPushAttrib(GL2.GL_TEXTURE_BIT | GL2.GL_ENABLE_BIT | GL2.GL_CURRENT_BIT);
+				try {
+					gl.glGetTexLevelParameteriv(GL2.GL_TEXTURE_2D, level, GL2.GL_TEXTURE_WIDTH, size, 0);
+					gl.glGetTexLevelParameteriv(GL2.GL_TEXTURE_2D, level, GL2.GL_TEXTURE_HEIGHT, size, 1);
+
+					VideoBounds bounds1 = new VideoBounds(size[0], size[1]);
+					buffer1 = minify(buffer0, bounds1);
+
+					gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+							GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, texture, level);
+					gl.glDrawBuffer(GL2.GL_COLOR_ATTACHMENT0);
+
+					gl.glActiveTexture(GL2.GL_TEXTURE0);
+					gl.glBindTexture(GL2.GL_TEXTURE_2D, buffer1.getTexture());
+					gl.glEnable(GL2.GL_TEXTURE_2D);
+
+					gl.glColor4f(1, 1, 1, 1);
+					support.ortho2D(bounds1);
+					support.quad2D(bounds1, new double[][] {{0,0},{1,0},{1,1},{0,1}});
+
+					if (buffer0 != this) buffer0.dispose();
+					buffer0 = buffer1;
+					buffer1 = null;
+
+					if (size[0] == 1 && size[1] == 1) {
+						break;
+					}
+				} finally {
+					gl.glFramebufferTexture2D(GL2.GL_FRAMEBUFFER,
+							GL2.GL_COLOR_ATTACHMENT0, GL2.GL_TEXTURE_2D, 0, 0);
+					gl.glPopAttrib();
+					if (buffer1 != null) buffer1.dispose();
+				}
+			}
+		} finally {
+			if (buffer0 != this) buffer0.dispose();
+		}
+	}
+ 
+	private IVideoBuffer minify(IVideoBuffer buffer0, final VideoBounds bounds1) {
+		IVideoBuffer buffer1 = null;
+		try {
+			buffer1 = support.createVideoBuffer(bounds1, buffer0.getColorMode());
+
+			Runnable operation = new Runnable() {
+				public void run() {
+					GL2 gl = context.getGL().getGL2();
+					gl.glActiveTexture(GL2.GL_TEXTURE0);
+					gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MIN_FILTER, GL2.GL_LINEAR);
+					gl.glTexParameteri(GL2.GL_TEXTURE_2D, GL2.GL_TEXTURE_MAG_FILTER, GL2.GL_LINEAR);
+					gl.glEnable(GL2.GL_TEXTURE_2D);
+					gl.glColor4f(1, 1, 1, 1);
+					support.ortho2D(bounds1);
+					support.quad2D(bounds1, new double[][] {{0,0},{1,0},{1,1},{0,1}});
+				}
+			};
+
+			int pushAttribs = GL2.GL_TEXTURE_BIT | GL2.GL_ENABLE_BIT | GL2.GL_CURRENT_BIT;
+			support.useFramebuffer(operation, pushAttribs, buffer1, buffer0);
+
+			IVideoBuffer result = buffer1;
+			buffer1 = null;
+			return result;
+
+		} finally {
+			if (buffer1 != null) buffer1.dispose();
+		}
+	}
+
 }
