@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2010 Yoshikazu Kuramochi
+ * Copyright (c) 2010,2011 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -294,6 +294,260 @@ public class BlendSupportImpl implements IBlendSupport {
 	}
 
 
+	public static class PremultAndMatteWithNormalCategory {
+
+		private static String[] createSource(String name, boolean dissolve) {
+			return new String[] {
+									"uniform sampler2D texDst;",
+									"uniform sampler2D texSrc;",
+									"uniform float opacity;",
+					dissolve ?		"uniform float dissolveSeed;" : "",
+									"",
+					String.format(	"vec4 blend_%s(vec4 pDst, vec4 pSrc, float opacity%s);", name, dissolve ? ", float dissolveSeed" : ""),
+									"",
+									"void main(void)",
+									"{",
+									"	vec4 dst = texture2D(texDst, gl_TexCoord[0].st);",
+									"	vec4 src = texture2D(texSrc, gl_TexCoord[1].st);",
+					String.format(	"	vec4 blend = blend_%s(dst, src, opacity%s);", name, dissolve ? ", dissolveSeed" : ""),
+									"	if (blend.a != 0.0) {",
+									"		gl_FragColor = blend/blend.a * dst.a;",
+									"	} else {",
+									"		gl_FragColor = vec4(0.0);",
+									"	}",
+									"}"
+			};
+		}
+
+		private static String[] createSource(String name) {
+			return createSource(name, false);
+		}
+
+		@ShaderSource/*(attach=BLEND_FUNCTIONS)*/
+		public static final String[] NONE = {
+			"uniform sampler2D texDst;",
+			"uniform sampler2D texSrc;",
+			"uniform float opacity;",
+			"",
+		//	"vec4 blend_none(vec4 pDst, vec4 pSrc, float opacity);",
+			"",
+			"void main(void)",
+			"{",
+			"	vec4 dst = texture2D(texDst, gl_TexCoord[0].st);",
+			"	vec4 src = texture2D(texSrc, gl_TexCoord[1].st);",
+		//	"	gl_FragColor = blend_none(dst, src, opacity) * dst.a;",
+			"	gl_FragColor = src * opacity * dst.a;",
+			"}"
+		};
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] NORMAL = createSource("normal");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DISSOLVE = createSource("dissolve", true);
+
+//		@ShaderSource(attach=BLEND_FUNCTIONS)
+//		public static final String[] DANCING_DISSOLVE = DISSOLVE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DARKEN = createSource("darken");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] MULTIPLY = createSource("multiply");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR_BURN = createSource("color_burn");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_BURN = createSource("linear_burn");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DARKER_COLOR = createSource("darker_color");
+
+		@ShaderSource
+		public static final String[] ADD = {
+			"uniform sampler2D texDst;",
+			"uniform sampler2D texSrc;",
+			"uniform float opacity;",
+			"",
+			"void main(void)",
+			"{",
+			"	vec4 dst = texture2D(texDst, gl_TexCoord[0].st);",
+			"	vec4 src = texture2D(texSrc, gl_TexCoord[1].st);",
+			"	gl_FragColor = vec4(src.rgb*opacity*dst.a + dst.rgb, dst.a);",
+			"}"
+		};
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LIGHTEN = createSource("lighten");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SCREEN = createSource("screen");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR_DODGE = createSource("color_dodge");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_DODGE = createSource("linear_dodge");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LIGHTER_COLOR = createSource("lighter_color");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] OVERLAY = createSource("overlay");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SOFT_LIGHT = createSource("soft_light");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HARD_LIGHT = createSource("hard_light");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_LIGHT = createSource("linear_light");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] VIVID_LIGHT = createSource("vivid_light");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] PIN_LIGHT = createSource("pin_light");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HARD_MIX = createSource("hard_mix");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DIFFERENCE = createSource("difference");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] EXCLUSION = createSource("exclusion");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HUE = createSource("hue");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SATURATION = createSource("saturation");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR = createSource("color");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LUMINOSITY = createSource("luminosity");
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] STENCIL_ALPHA = Premult.STENCIL_ALPHA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] STENCIL_LUMA = Premult.STENCIL_LUMA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SILHOUETTE_ALPHA = Premult.SILHOUETTE_ALPHA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SILHOUETTE_LUMA = Premult.SILHOUETTE_LUMA;
+
+	}
+
+
+	public static class PremultAndMatteWithoutNormalCategory {
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] NONE = Premult.NONE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] NORMAL = Premult.NORMAL;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DISSOLVE = Premult.DISSOLVE;
+
+//		@ShaderSource(attach=BLEND_FUNCTIONS)
+//		public static final String[] DANCING_DISSOLVE = DISSOLVE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DARKEN = PremultAndMatteWithNormalCategory.DARKEN;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] MULTIPLY = PremultAndMatteWithNormalCategory.MULTIPLY;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR_BURN = PremultAndMatteWithNormalCategory.COLOR_BURN;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_BURN = PremultAndMatteWithNormalCategory.LINEAR_BURN;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DARKER_COLOR = PremultAndMatteWithNormalCategory.DARKER_COLOR;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] ADD = PremultAndMatteWithNormalCategory.ADD;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LIGHTEN = PremultAndMatteWithNormalCategory.LIGHTEN;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SCREEN = PremultAndMatteWithNormalCategory.SCREEN;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR_DODGE = PremultAndMatteWithNormalCategory.COLOR_DODGE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_DODGE = PremultAndMatteWithNormalCategory.LINEAR_DODGE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LIGHTER_COLOR = PremultAndMatteWithNormalCategory.LIGHTER_COLOR;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] OVERLAY = PremultAndMatteWithNormalCategory.OVERLAY;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SOFT_LIGHT = PremultAndMatteWithNormalCategory.SOFT_LIGHT;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HARD_LIGHT = PremultAndMatteWithNormalCategory.HARD_LIGHT;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LINEAR_LIGHT = PremultAndMatteWithNormalCategory.LINEAR_LIGHT;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] VIVID_LIGHT = PremultAndMatteWithNormalCategory.VIVID_LIGHT;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] PIN_LIGHT = PremultAndMatteWithNormalCategory.PIN_LIGHT;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HARD_MIX = PremultAndMatteWithNormalCategory.HARD_MIX;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] DIFFERENCE = PremultAndMatteWithNormalCategory.DIFFERENCE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] EXCLUSION = PremultAndMatteWithNormalCategory.EXCLUSION;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] HUE = PremultAndMatteWithNormalCategory.HUE;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SATURATION = PremultAndMatteWithNormalCategory.SATURATION;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] COLOR = PremultAndMatteWithNormalCategory.COLOR;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] LUMINOSITY = PremultAndMatteWithNormalCategory.LUMINOSITY;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] STENCIL_ALPHA = Premult.STENCIL_ALPHA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] STENCIL_LUMA = Premult.STENCIL_LUMA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SILHOUETTE_ALPHA = Premult.SILHOUETTE_ALPHA;
+
+		@ShaderSource(attach=BLEND_FUNCTIONS)
+		public static final String[] SILHOUETTE_LUMA = Premult.SILHOUETTE_LUMA;
+
+	}
+
+
 	private final IVideoRenderSupport support;
 
 	private final IShaderRegistry shaders;
@@ -313,6 +567,11 @@ public class BlendSupportImpl implements IBlendSupport {
 		return UnmultSrc.class;
 	}
 
+	public Class<?> getPremultAndMatteClass(boolean normalCategory) {
+		return normalCategory ? PremultAndMatteWithNormalCategory.class
+							  : PremultAndMatteWithoutNormalCategory.class;
+	}
+
 	public void setProgramsClass(Class<?> programsClass) {
 		Map<BlendMode, IShaderProgram> programs = new HashMap<BlendMode, IShaderProgram>();
 
