@@ -28,6 +28,8 @@ import static ftgl.FTGL.FT_Err_Ok;
 
 import java.io.File;
 import java.io.FileFilter;
+import java.lang.reflect.InvocationTargetException;
+import java.lang.reflect.Method;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.Comparator;
@@ -58,15 +60,60 @@ public class FontListImpl implements FontList {
 	private static final Logger _logger = LoggerFactory.getLogger(FontListImpl.class);
 
 
-	private static final List<String> FONT_FILE_EXTENSIONS = Arrays.asList("ttf", "ttc", "dfont", "otf");
+	private static final List<String> FONT_FILE_EXTENSIONS = Arrays.asList(
+			"dfont",		// TrueType データフォークフォント
+			"otf",			// PostScript OpenType フォント
+			"ttf",			// TrueType OpenType フォント
+			"ttc",			// TrueType コレクションフォント
+			"suit",			// フォントスーツケース
+			"pfb",			// PostScript Type1 アウトラインフォント (バイナリ形式)
+			"pfa"			// PostScript Type1 アウトラインフォント (ASCII形式)
+	);
+
+	private static final List<Integer> FONT_FILE_FILETYPES = Arrays.asList(
+			0x64666f6e,		// dfon : TrueType データフォークフォント
+			0x4f54544f,		// OTTO : PostScript OpenType フォント
+			0x74746366,		// ttcf : TrueType コレクションフォント
+			0x4646494c,		// FFIL : フォントスーツケース
+			0x6666696c,		// ffil : フォントスーツケース
+			0x73666e74,		// sfnt : フォントスーツケース
+			0x7466696c,		// tfil : フォントスーツケース
+			0x4c57464e		// LWFN : PostScript Type1 アウトラインフォント (Mac)
+	);
 
 	private static final FileFilter FONT_FILE_FILTER = new FileFilter() {
+		private final Method getFileTypeMethod;
+		{
+			Method m = null;
+			try {
+				Class<?> c = Class.forName("com.apple.eio.FileManager");
+				m = c.getMethod("getFileType", String.class);
+			} catch (SecurityException e) {
+			} catch (ClassNotFoundException e) {
+			} catch (NoSuchMethodException e) {
+			}
+			getFileTypeMethod = m;
+		}
+
 		public boolean accept(File pathname) {
 			String name = pathname.getName();
 			int lastDot = name.indexOf('.');
 			if (lastDot != -1) {
 				String extension = name.substring(lastDot+1).toLowerCase();
-				return FONT_FILE_EXTENSIONS.contains(extension);
+				if (FONT_FILE_EXTENSIONS.contains(extension)) {
+					return true;
+				}
+			}
+			if (getFileTypeMethod != null) {
+				try {
+					Integer fileType = (Integer) getFileTypeMethod.invoke(null, pathname.getAbsolutePath());
+					if (FONT_FILE_FILETYPES.contains(fileType)) {
+						return true;
+					}
+				} catch (IllegalArgumentException e) {
+				} catch (IllegalAccessException e) {
+				} catch (InvocationTargetException e) {
+				}
 			}
 			return false;
 		}
