@@ -125,7 +125,7 @@ public class ProjectEncoderImpl implements ProjectEncoder {
 		}
 
 		private double[] toArray(Color c) {
-			return new double[] { c.r, c.g, c.b, c.a };
+			return new double[] { c.rawRed, c.rawGreen, c.rawBlue, c.rawAlpha };
 		}
 
 		private int[] toArray(Size2i d) {
