@@ -23,6 +23,8 @@
 
 package ch.kuramo.javie.core.internal.services;
 
+import java.util.Set;
+
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
@@ -31,6 +33,7 @@ import ch.kuramo.javie.api.ColorMode;
 import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.Camera;
+import ch.kuramo.javie.core.Light;
 import ch.kuramo.javie.core.services.RenderContext;
 
 public class RenderContextProxy
@@ -85,6 +88,14 @@ public class RenderContextProxy
 		getImpl().setCamera(camera);
 	}
 
+	public Set<Light> getLights() {
+		return getImpl().getLights();
+	}
+
+	public void setLights(Set<Light> lights) {
+		getImpl().setLights(lights);
+	}
+
 	public AudioMode getAudioMode() {
 		return getImpl().getAudioMode();
 	}
