@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,9 +26,9 @@ package ch.kuramo.javie.core.services;
 import java.util.Map;
 
 import ch.kuramo.javie.core.AnimatableValue;
-import ch.kuramo.javie.core.RenderContext;
+import ch.kuramo.javie.core.CoreContext;
 
-public interface AnimatableValueCollector extends RenderContext {
+public interface AnimatableValueCollector extends CoreContext {
 
 	Map<AnimatableValue<?>, ?> collect();
 
