@@ -23,6 +23,8 @@
 
 package ch.kuramo.javie.core.services;
 
+import java.util.Set;
+
 import javax.media.opengl.GL;
 import javax.media.opengl.glu.GLU;
 
@@ -32,6 +34,7 @@ import ch.kuramo.javie.api.Resolution;
 import ch.kuramo.javie.api.Time;
 import ch.kuramo.javie.core.Camera;
 import ch.kuramo.javie.core.CoreContext;
+import ch.kuramo.javie.core.Light;
 
 public interface RenderContext extends CoreContext {
 
@@ -55,6 +58,10 @@ public interface RenderContext extends CoreContext {
 
 	void setCamera(Camera camera);
 
+	Set<Light> getLights();
+
+	void setLights(Set<Light> lights);
+
 
 	AudioMode getAudioMode();
 
