@@ -26,6 +26,22 @@
 #import <QTKit/QTTime.h>
 
 
+NSString* HandleToNSString(Handle text)
+{
+	// OSXではハンドルのロックは(SetHandleSizeを使わないなら)必要ないらしいのでロックしない。
+	
+	Size textLen = GetHandleSize(text);
+	
+	NSMutableData* textData = [NSMutableData dataWithCapacity:textLen+1];
+	[textData appendBytes:*text length:textLen];
+	
+	char nullTerm = 0;
+	[textData appendBytes:&nullTerm length:1];
+	
+	return [NSString stringWithCString:[textData bytes] encoding:[NSString defaultCStringEncoding]];
+}
+
+
 @interface QTMovieOutput (private)
 
 -(void) enterMovies;
@@ -112,6 +128,236 @@ static OSErr progressProc(Movie movie, short message, short whatOperation, Fixed
 	ExitMovies();
 }
 
++(jint) doVideoCompressorSettings:(QTAtomContainer)defaultSettings
+								 :(double)defaultFrameRate
+								 :(BOOL)showDialog
+								 :(QTAtomContainer*)newSettings
+								 :(short*)newDepth
+								 :(double*)newFrameRate
+								 :(NSString**)newSettingsAsText
+{
+	jint error = noErr;
+	
+	ComponentInstance ci = 0;
+	SCSpatialSettings ss;
+	SCTemporalSettings ts;
+	QTAtomContainer ac = NULL;
+	Handle text = NULL;
+	
+	error = OpenADefaultComponent(StandardCompressionType, StandardCompressionSubType, &ci);
+	if (error != noErr) {
+		NSLog(@"OpenADefaultComponent: error %d", error);
+		goto bail;
+	}
+	
+//	long scPreferences = scAllowEncodingWithCompressionSession;
+//	error = SCSetInfo(ci, scPreferenceFlagsType, &scPreferences);
+//	if (error != noErr) {
+//		NSLog(@"SCSetInfo with scPreferenceFlagsType: error %d", error);
+//		goto bail;
+//	}
+	
+	if (defaultSettings == NULL) {
+		ss.codecType = kAnimationCodecType;
+		ss.codec = 0;
+		ss.depth = 24;
+		ss.spatialQuality = codecLosslessQuality;
+		
+		error = SCSetInfo(ci, scSpatialSettingsType, &ss);
+		if (error != noErr) {
+			NSLog(@"SCSetInfo with scSpatialSettingsType: error %d", error);
+			goto bail;
+		}
+		
+		ts.keyFrameRate = 0;
+		ts.temporalQuality = 0;
+		
+	} else {
+		error = SCSetSettingsFromAtomContainer(ci, defaultSettings);
+		if (error != noErr) {
+			NSLog(@"SCSetSettingsFromAtomContainer: error %d", error);
+			goto bail;
+		}
+		
+		error = SCGetInfo(ci, scTemporalSettingsType, &ts);
+		if (error != noErr) {
+			NSLog(@"SCGetInfo with scTemporalSettingsType: error %d", error);
+			goto bail;
+		}
+	}
+	
+	ts.frameRate = X2Fix(defaultFrameRate);
+	
+	error = SCSetInfo(ci, scTemporalSettingsType, &ts);
+	if (error != noErr) {
+		NSLog(@"SCSetInfo with scTemporalSettingsType: error %d", error);
+		goto bail;
+	}
+	
+	if (showDialog) {
+		error = SCRequestSequenceSettings(ci);
+		if (error != noErr) {
+			NSLog(@"SCRequestSequenceSettings: error %d", error);
+			goto bail;
+		}
+	}
+	
+	error = SCGetSettingsAsAtomContainer(ci, &ac);
+	if (error != noErr) {
+		NSLog(@"SCGetSettingsAsAtomContainer: error %d", error);
+		goto bail;
+	}
+	
+	error = SCGetInfo(ci, scSpatialSettingsType, &ss);
+	if (error != noErr) {
+		NSLog(@"SCGetInfo with scSpatialSettingsType: error %d", error);
+		goto bail;
+	}
+	
+	error = SCGetInfo(ci, scTemporalSettingsType, &ts);
+	if (error != noErr) {
+		NSLog(@"SCGetInfo with scTemporalSettingsType: error %d", error);
+		goto bail;
+	}
+	
+	error = SCGetSettingsAsText(ci, &text);
+	if (error != noErr) {
+		NSLog(@"SCGetSettingsAsText: error %d", error);
+		goto bail;
+	}
+	
+bail:
+	if (error == noErr) {
+		*newSettings = ac;
+		*newDepth = ss.depth;
+		*newFrameRate = Fix2X(ts.frameRate);
+		*newSettingsAsText = HandleToNSString(text);
+	} else {
+		if (ac != NULL) QTDisposeAtomContainer(ac);
+	}
+	if (text != NULL) DisposeHandle(text);
+	if (ci != 0) CloseComponent(ci);
+	return error;
+}
+
++(jint) doAudioCompressorSettings:(QTAtomContainer)defaultSettings
+								 :(double)defaultSampleRate
+								 :(BOOL)showDialog
+								 :(QTAtomContainer*)newSettings
+								 :(double*)newSampleRate
+								 :(NSString**)newSettingsAsText
+{
+	jint error = noErr;
+	
+	ComponentInstance ci = 0;
+	QTAtomContainer ac = NULL;
+	Handle text = NULL;
+	
+	error = OpenADefaultComponent(StandardCompressionType, StandardCompressionSubTypeAudio, &ci);
+	if (error != noErr) {
+		NSLog(@"OpenADefaultComponent: error %d", error);
+		goto bail;
+	}
+	
+	AudioStreamBasicDescription asbd;
+	
+	if (defaultSettings == NULL) {
+		AudioChannelLayoutTag layoutTag = kAudioChannelLayoutTag_Stereo;
+		UInt32 layoutSize;
+		error = AudioFormatGetPropertyInfo(kAudioFormatProperty_ChannelLayoutForTag,
+										   sizeof(AudioChannelLayoutTag), &layoutTag, &layoutSize);
+		if (error != noErr) {
+			NSLog(@"AudioFormatGetPropertyInfo: error %d", error);
+			goto bail;
+		}
+		
+		NSMutableData* layoutData = [NSMutableData dataWithLength:layoutSize];
+		error = AudioFormatGetProperty(kAudioFormatProperty_ChannelLayoutForTag,
+									   sizeof(AudioChannelLayoutTag), &layoutTag, &layoutSize, [layoutData mutableBytes]);
+		if (error != noErr) {
+			NSLog(@"AudioFormatGetProperty: error %d", error);
+			goto bail;
+		}
+		
+		error = QTSetComponentProperty(ci, kQTPropertyClass_SCAudio, kQTSCAudioPropertyID_ChannelLayout,
+									   layoutSize, [layoutData bytes]);
+		if (error != noErr) {
+			NSLog(@"QTSetComponentProperty with kQTSCAudioPropertyID_ChannelLayout: error %d", error);
+			goto bail;
+		}
+		
+		asbd.mFormatID = kAudioFormatLinearPCM;
+		asbd.mFormatFlags = kAudioFormatFlagIsPacked | kAudioFormatFlagsNativeEndian | kAudioFormatFlagIsSignedInteger;
+		asbd.mBitsPerChannel = 16;
+		asbd.mChannelsPerFrame = 2;
+		asbd.mBytesPerFrame = 4;
+		asbd.mFramesPerPacket = 1;
+		asbd.mBytesPerPacket = asbd.mBytesPerFrame * asbd.mFramesPerPacket;
+		
+	} else {
+		error = SCSetSettingsFromAtomContainer(ci, defaultSettings);
+		if (error != noErr) {
+			NSLog(@"SCSetSettingsFromAtomContainer: error %d", error);
+			goto bail;
+		}
+		
+		error = QTGetComponentProperty(ci, kQTPropertyClass_SCAudio, kQTSCAudioPropertyID_BasicDescription,
+									   sizeof(asbd), &asbd, NULL);
+		if (error != noErr) {
+			NSLog(@"QTGetComponentProperty with kQTSCAudioPropertyID_BasicDescription: error %d", error);
+			goto bail;
+		}
+	}
+	
+	asbd.mSampleRate = defaultSampleRate;
+	
+	error = QTSetComponentProperty(ci, kQTPropertyClass_SCAudio, kQTSCAudioPropertyID_BasicDescription,
+								   sizeof(asbd), &asbd);
+	if (error != noErr) {
+		NSLog(@"QTSetComponentProperty with kQTSCAudioPropertyID_BasicDescription: error %d", error);
+		goto bail;
+	}
+	
+	if (showDialog) {
+		error = SCRequestImageSettings(ci);
+		if (error != noErr) {
+			NSLog(@"SCRequestImageSettings: error %d", error);
+			goto bail;
+		}
+	}
+	
+	error = SCGetSettingsAsAtomContainer(ci, &ac);
+	if (error != noErr) {
+		NSLog(@"SCGetSettingsAsAtomContainer: error %d", error);
+		goto bail;
+	}
+	
+	error = QTGetComponentProperty(ci, kQTPropertyClass_SCAudio, kQTSCAudioPropertyID_BasicDescription,
+								   sizeof(asbd), &asbd, NULL);
+	if (error != noErr) {
+		NSLog(@"QTGetComponentProperty with kQTSCAudioPropertyID_BasicDescription: error %d", error);
+		goto bail;
+	}
+	
+	error = SCGetSettingsAsText(ci, &text);
+	if (error != noErr) {
+		NSLog(@"SCGetSettingsAsText: error %d", error);
+		goto bail;
+	}
+	
+bail:
+	if (error == noErr) {
+		*newSettings = ac;
+		*newSampleRate = asbd.mSampleRate;
+		*newSettingsAsText = HandleToNSString(text);
+	} else {
+		if (ac != NULL) QTDisposeAtomContainer(ac);
+	}
+	if (text != NULL) DisposeHandle(text);
+	if (ci != 0) CloseComponent(ci);
+	return error;
+}
+
 -(jint) openMovieExportComponent
 {
 	ComponentDescription compDesc;
@@ -135,69 +381,37 @@ static OSErr progressProc(Movie movie, short message, short whatOperation, Fixed
 	return noErr;
 }
 
--(jint) doUserDialog
+-(jint) setCompressorSettings:(QTAtomContainer)videoSettings
+							 :(QTAtomContainer)audioSettings
 {
-	Boolean canceled = false;
-	jint error = MovieExportDoUserDialog(mExporter, NULL, NULL, 0, 0, &canceled);
-	if (error != noErr) {
-		NSLog(@"MovieExportDoUserDialog: error %d", error);
-		return error;
+	if (videoSettings == NULL && audioSettings == NULL) {
+		return noErr;
 	}
-	return canceled ? userCanceledErr : noErr;
-}
-
--(jint) getSettings:(JNIEnv*)jniEnv
-				   :(jbyteArray*)settings
-{
+	
 	jint error = noErr;
-	
 	QTAtomContainer ac = NULL;
-	
-	error = MovieExportGetSettingsAsAtomContainer(mExporter, &ac);
-	if (error != noErr) {
-		NSLog(@"MovieExportGetSettingsAsAtomContainer: error %d", error);
-		goto bail;
-	}
-	
-	size_t size = GetHandleSize(ac);
-	jbyteArray jba = (*jniEnv)->NewByteArray(jniEnv, size);
-	if (jba == NULL) {
-		NSLog(@"NewByteArray: failed");
-		error = memFullErr;
-		goto bail;
-	}
-	
-	HLock(ac);
-	(*jniEnv)->SetByteArrayRegion(jniEnv, jba, 0, size, (jbyte*)*ac);
-	HUnlock(ac);
-	
-	*settings = jba;
-	
-bail:
-	if (ac != NULL) QTDisposeAtomContainer(ac);
-	
-	return error;
-}
-
--(jint) setSettings:(JNIEnv*)jniEnv
-				   :(jbyteArray)settings
-{
-	jint error = noErr;
-	
-	char* p = NULL;
-	QTAtomContainer ac = NULL;
-	
-	p = (*jniEnv)->GetPrimitiveArrayCritical(jniEnv, settings, NULL);
-	if (p == NULL) {
-		NSLog(@"GetPrimitiveArrayCritical: failed");
-		error = memFullErr;
-		goto bail;
-	}
-	
-	error = PtrToHand(p, (Handle*)&ac, (*jniEnv)->GetArrayLength(jniEnv, settings));
-	if (error != noErr) {
-		NSLog(@"PtrToHand: error %d", error);
-		goto bail;
+	QTAtomContainer merged = NULL;
+		
+	if (videoSettings != NULL && audioSettings == NULL) {
+		ac = videoSettings;
+		
+	} else if (videoSettings == NULL && audioSettings != NULL) {
+		ac = audioSettings;
+		
+	} else if (videoSettings != NULL && audioSettings != NULL) {
+		error = QTCopyAtom(videoSettings, kParentAtomIsContainer, &merged);
+		if (error != noErr) {
+			NSLog(@"QTCopyAtom: error %d", error);
+			goto bail;
+		}
+		
+		error = QTInsertChildren(merged, kParentAtomIsContainer, audioSettings);
+		if (error != noErr) {
+			NSLog(@"QTInsertChildren: error %d", error);
+			goto bail;
+		}
+		
+		ac = merged;
 	}
 	
 	error = MovieExportSetSettingsFromAtomContainer(mExporter, ac);
@@ -207,9 +421,7 @@ bail:
 	}
 	
 bail:
-	if (ac != NULL) QTDisposeAtomContainer(ac);
-	if (p != NULL) (*jniEnv)->ReleasePrimitiveArrayCritical(jniEnv, settings, p, 0);
-	
+	if (merged != NULL) QTDisposeAtomContainer(merged);
 	return error;
 }
 
@@ -258,7 +470,7 @@ bail:
 -(jint) addAudioSource:(long)aChannels
 					  :(long)aSampleRate
 					  :(long)aSampleSize
-					  :(Boolean)aFloat
+					  :(BOOL)aFloat
 					  :(TimeValue64)aDuration
 {
 	mAudioChannels = aChannels;
