@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2009 Yoshikazu Kuramochi
+ * Copyright (c) 2009,2010 Yoshikazu Kuramochi
  * All rights reserved.
  * 
  * Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -25,10 +25,6 @@ package ch.kuramo.javie.effects;
 
 import ch.kuramo.javie.api.plugin.JaviePlugin;
 
-public class JavieEffectsPlugin implements JaviePlugin {
-
-	public JavieEffectsPlugin() {
-		super();
-	}
+public class JavieEffectsPlugin extends JaviePlugin {
 
 }
