@@ -329,8 +329,7 @@ public class LensBlur {
 			uniforms.add(new GLUniformData("nonlinear", (float)nonlinear));
 			uniforms.add(new GLUniformData("o_div_nmo", (float)(1/(nonlinear-1))));
 
-			ColorMode ctxcm = context.getColorMode();
-			buffer1 = support.createVideoBuffer(resultBounds, ctxcm.isFloat() ? ctxcm : ColorMode.RGBA16_FLOAT);
+			buffer1 = support.createVideoBuffer(resultBounds, ColorMode.RGBA32_FLOAT);
 
 			source.setTextureWrapMode(repeatEdgePixels ? TextureWrapMode.CLAMP_TO_EDGE : TextureWrapMode.CLAMP_TO_BORDER);
 
@@ -341,7 +340,8 @@ public class LensBlur {
 			} else {
 				uniforms.add(new GLUniformData("depTexOffset", 2, toFloatBuffer(
 						(depthBounds.width-srcBounds.width)*0.5, (depthBounds.height-srcBounds.height)*0.5)));
-				uniforms.add(new GLUniformData("o_div_depsz", (float)(1.0/depthBounds.width)));
+				uniforms.add(new GLUniformData("o_div_depsz", 2, toFloatBuffer(
+						1.0/depthBounds.width, 1.0/depthBounds.height)));
 			}
 			depthBuffer.setTextureFilter(mipmap ? TextureFilter.MIPMAP : TextureFilter.LINEAR);
 			depthBuffer.setTextureWrapMode(TextureWrapMode.CLAMP_TO_EDGE);
@@ -611,7 +611,7 @@ public class LensBlur {
 				"",
 				"#ifndef STRETCH_DEPTH",
 				"	uniform vec2 depTexOffset;",	// (depTexSize-texSize)*0.5
-				"	uniform float o_div_depsz;",	// 1.0/depTexSize
+				"	uniform vec2 o_div_depsz;",		// 1.0/depTexSize
 				"#endif",
 				"",
 				"varying vec4 frontColorA;",
@@ -801,9 +801,7 @@ public class LensBlur {
 		"void main(void)",
 		"{",
 		"	vec2 irisCoord = (gl_PointCoord - 0.5) * pointCoordAdj + 0.5;",
-		"	vec4 irisColor = texture2D(iris, irisCoord);",
-		"	irisColor.a = dot(irisColor.rgb, vec3(0.299, 0.587, 0.114));",
-		"	gl_FragColor = vec4(1.0) * irisColor;",
+		"	gl_FragColor = texture2D(iris, irisCoord);",
 		"}"
 	};
 
