@@ -33,13 +33,13 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] BLUE_SCREEN_KEY = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform float threshold;",
 		"uniform float t_minus_c;",
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 		"	if (color.a != 0.0) {",
 		"		vec3 rgb = color.rgb/color.a;",
 		"		color.a = clamp(color.a*(threshold-rgb.b*(1.0-rgb.r))/t_minus_c, 0.0, color.a);",
@@ -53,13 +53,13 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] BLUE_SCREEN_KEY_MASK_ONLY = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform float threshold;",
 		"uniform float t_minus_c;",
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 		"	if (color.a != 0.0) {",
 		"		vec3 rgb = color.rgb/color.a;",
 		"		float a = clamp(color.a*(threshold-rgb.b*(1.0-rgb.r))/t_minus_c, 0.0, color.a);",
@@ -72,13 +72,13 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] GREEN_SCREEN_KEY = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform float threshold;",
 		"uniform float t_minus_c;",
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 		"	if (color.a != 0.0) {",
 		"		vec3 rgb = color.rgb/color.a;",
 		"		color.a = clamp(color.a*(threshold-rgb.g*(1.0-rgb.r))/t_minus_c, 0.0, color.a);",
@@ -92,13 +92,13 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] GREEN_SCREEN_KEY_MASK_ONLY = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
 		"uniform float threshold;",
 		"uniform float t_minus_c;",
 		"",
 		"void main(void)",
 		"{",
-		"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+		"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 		"	if (color.a != 0.0) {",
 		"		vec3 rgb = color.rgb/color.a;",
 		"		float a = clamp(color.a*(threshold-rgb.g*(1.0-rgb.r))/t_minus_c, 0.0, color.a);",
@@ -111,7 +111,8 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] SMOOTHING_LOW = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
+		"uniform vec2 neib[8];",
 		"",
 		"void main(void)",
 		"{",
@@ -119,15 +120,15 @@ public class KeyingShaders {
 		"	vec4 sum = vec4(0.0);",
 		"	int n = 0;",
 		"	vec4 c;",
-		"	c = texture2DRect(texture, coord+vec2(-1.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
-		"	c = texture2DRect(texture, coord                 ); if (c.a != 0.0) { ++n; sum += 0.2500 * c; }",
+		"	c = texture2D(texture, coord+neib[0]); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
+		"	c = texture2D(texture, coord+neib[1]); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
+		"	c = texture2D(texture, coord+neib[2]); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
+		"	c = texture2D(texture, coord+neib[3]); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
+		"	c = texture2D(texture, coord+neib[4]); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
+		"	c = texture2D(texture, coord+neib[5]); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
+		"	c = texture2D(texture, coord+neib[6]); if (c.a != 0.0) { ++n; sum += 0.1250 * c; }",
+		"	c = texture2D(texture, coord+neib[7]); if (c.a != 0.0) { ++n; sum += 0.0625 * c; }",
+		"	c = texture2D(texture, coord        ); if (c.a != 0.0) { ++n; sum += 0.2500 * c; }",
 		"",
 		"	gl_FragColor = (n > 0 && n < 9) ? sum : c;",
 		"}"
@@ -135,7 +136,8 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] SMOOTHING_HIGH = {
-		"uniform sampler2DRect texture;",
+		"uniform sampler2D texture;",
+		"uniform vec2 neib[24];",
 		"",
 		"void main(void)",
 		"{",
@@ -143,31 +145,31 @@ public class KeyingShaders {
 		"	vec4 sum = vec4(0.0);",
 		"	int n = 0;",
 		"	vec4 c;",
-		"	c = texture2DRect(texture, coord+vec2(-2.0, -2.0)); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0, -2.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0, -2.0)); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0, -2.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 2.0, -2.0)); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-2.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 2.0, -1.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-2.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 2.0,  0.0)); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-2.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 2.0,  1.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-2.0,  2.0)); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
-		"	c = texture2DRect(texture, coord+vec2(-1.0,  2.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 0.0,  2.0)); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 1.0,  2.0)); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
-		"	c = texture2DRect(texture, coord+vec2( 2.0,  2.0)); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
-		"	c = texture2DRect(texture, coord                 ); if (c.a != 0.0) { ++n; sum += 0.150183 * c; }",
+		"	c = texture2D(texture, coord+neib[ 0]); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
+		"	c = texture2D(texture, coord+neib[ 1]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[ 2]); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
+		"	c = texture2D(texture, coord+neib[ 3]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[ 4]); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
+		"	c = texture2D(texture, coord+neib[ 5]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[ 6]); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
+		"	c = texture2D(texture, coord+neib[ 7]); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
+		"	c = texture2D(texture, coord+neib[ 8]); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
+		"	c = texture2D(texture, coord+neib[ 9]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[10]); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
+		"	c = texture2D(texture, coord+neib[11]); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
+		"	c = texture2D(texture, coord+neib[12]); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
+		"	c = texture2D(texture, coord+neib[13]); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
+		"	c = texture2D(texture, coord+neib[14]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[15]); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
+		"	c = texture2D(texture, coord+neib[16]); if (c.a != 0.0) { ++n; sum += 0.095238 * c; }",
+		"	c = texture2D(texture, coord+neib[17]); if (c.a != 0.0) { ++n; sum += 0.058608 * c; }",
+		"	c = texture2D(texture, coord+neib[18]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[19]); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
+		"	c = texture2D(texture, coord+neib[20]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[21]); if (c.a != 0.0) { ++n; sum += 0.025641 * c; }",
+		"	c = texture2D(texture, coord+neib[22]); if (c.a != 0.0) { ++n; sum += 0.014652 * c; }",
+		"	c = texture2D(texture, coord+neib[23]); if (c.a != 0.0) { ++n; sum += 0.003663 * c; }",
+		"	c = texture2D(texture, coord         ); if (c.a != 0.0) { ++n; sum += 0.150183 * c; }",
 		"",
 		"	gl_FragColor = (n > 0 && n < 25) ? sum : c;",
 		"}"
@@ -175,7 +177,7 @@ public class KeyingShaders {
 
 	private static String[] createChromaKeySource(boolean maskOnly) {
 		return new String[] {
-				"uniform sampler2DRect texture;",
+				"uniform sampler2D texture;",
 				"uniform vec2 keyUV;",
 				"uniform float similarity;",
 				"uniform float blend;",
@@ -188,7 +190,7 @@ public class KeyingShaders {
 				"",
 				"void main(void)",
 				"{",
-				"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+				"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 				"	float a1, a2;",
 				"",
 				"	if (color.a != 0.0) {",
@@ -226,8 +228,9 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] CHROMA_KEY_SMOOTHING_LOW = {
-		"uniform sampler2DRect tex0;",
-		"uniform sampler2DRect tex1;",
+		"uniform sampler2D tex0;",
+		"uniform sampler2D tex1;",
+		"uniform vec2 neib[8];",
 		"",
 		"void main(void)",
 		"{",
@@ -236,15 +239,15 @@ public class KeyingShaders {
 		"	int n = 0;",
 		"	vec2 d;",
 		"	vec4 c;",
-		"	d = coord+vec2(-1.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2DRect(tex0, d);",
-		"	d = coord                 ; c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; c = texture2DRect(tex0, d); sum += 0.2500 * c;",
+		"	d = coord+neib[0]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2D(tex0, d);",
+		"	d = coord+neib[1]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2D(tex0, d);",
+		"	d = coord+neib[2]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2D(tex0, d);",
+		"	d = coord+neib[3]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2D(tex0, d);",
+		"	d = coord+neib[4]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2D(tex0, d);",
+		"	d = coord+neib[5]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2D(tex0, d);",
+		"	d = coord+neib[6]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.1250 * texture2D(tex0, d);",
+		"	d = coord+neib[7]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.0625 * texture2D(tex0, d);",
+		"	d = coord        ; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; c = texture2D(tex0, d); sum += 0.2500 * c;",
 		"",
 		"	gl_FragColor = (n > 0 && n < 9) ? sum : c;",
 		"}"
@@ -252,8 +255,9 @@ public class KeyingShaders {
 
 	@ShaderSource
 	public static final String[] CHROMA_KEY_SMOOTHING_HIGH = {
-		"uniform sampler2DRect tex0;",
-		"uniform sampler2DRect tex1;",
+		"uniform sampler2D tex0;",
+		"uniform sampler2D tex1;",
+		"uniform vec2 neib[24];",
 		"",
 		"void main(void)",
 		"{",
@@ -262,31 +266,31 @@ public class KeyingShaders {
 		"	int n = 0;",
 		"	vec2 d;",
 		"	vec4 c;",
-		"	d = coord+vec2(-2.0, -2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0, -2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0, -2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0, -2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 2.0, -2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-2.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 2.0, -1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-2.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 2.0,  0.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-2.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 2.0,  1.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-2.0,  2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2DRect(tex0, d);",
-		"	d = coord+vec2(-1.0,  2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 0.0,  2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 1.0,  2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2DRect(tex0, d);",
-		"	d = coord+vec2( 2.0,  2.0); c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2DRect(tex0, d);",
-		"	d = coord                 ; c = texture2DRect(tex1, d); if (c.a != 0.0) { ++n; }; c = texture2DRect(tex0, d); sum += 0.150183 * c;",
+		"	d = coord+neib[ 0]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2D(tex0, d);",
+		"	d = coord+neib[ 1]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[ 2]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2D(tex0, d);",
+		"	d = coord+neib[ 3]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[ 4]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2D(tex0, d);",
+		"	d = coord+neib[ 5]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[ 6]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2D(tex0, d);",
+		"	d = coord+neib[ 7]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2D(tex0, d);",
+		"	d = coord+neib[ 8]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2D(tex0, d);",
+		"	d = coord+neib[ 9]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[10]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2D(tex0, d);",
+		"	d = coord+neib[11]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2D(tex0, d);",
+		"	d = coord+neib[12]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2D(tex0, d);",
+		"	d = coord+neib[13]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2D(tex0, d);",
+		"	d = coord+neib[14]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[15]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2D(tex0, d);",
+		"	d = coord+neib[16]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.095238 * texture2D(tex0, d);",
+		"	d = coord+neib[17]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.058608 * texture2D(tex0, d);",
+		"	d = coord+neib[18]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[19]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2D(tex0, d);",
+		"	d = coord+neib[20]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[21]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.025641 * texture2D(tex0, d);",
+		"	d = coord+neib[22]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.014652 * texture2D(tex0, d);",
+		"	d = coord+neib[23]; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; sum += 0.003663 * texture2D(tex0, d);",
+		"	d = coord         ; c = texture2D(tex1, d); if (c.a != 0.0) { ++n; }; c = texture2D(tex0, d); sum += 0.150183 * c;",
 		"",
 		"	gl_FragColor = (n > 0 && n < 25) ? sum : c;",
 		"}"
@@ -327,7 +331,7 @@ public class KeyingShaders {
 		List<String> list = new ArrayList<String>(Arrays.asList(new String[]{
 				"vec3 rgb2hsl(vec3 rgb);",
 				"",
-				"uniform sampler2DRect texture;",
+				"uniform sampler2D texture;",
 				"uniform vec3 similarityMin;",
 				"uniform vec3 similarityMax;",
 				"uniform vec3 blendMin;",
@@ -343,7 +347,7 @@ public class KeyingShaders {
 				"",
 				"void main(void)",
 				"{",
-				"	vec4 color = texture2DRect(texture, gl_TexCoord[0].st);",
+				"	vec4 color = texture2D(texture, gl_TexCoord[0].st);",
 				"	if (color.a != 0.0) {",
 				"		vec3 unmult = color.rgb/color.a;",
 				"		vec3 hsl = rgb2hsl(unmult);",
