@@ -25,10 +25,14 @@ package ch.kuramo.javie.effects.simulation;
 
 import java.nio.FloatBuffer;
 import java.util.HashSet;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Random;
 import java.util.Set;
 
 import javax.media.opengl.GL2;
 import javax.media.opengl.GLUniformData;
+import javax.vecmath.Vector3d;
 
 import ch.kuramo.javie.api.Color;
 import ch.kuramo.javie.api.IAnimatableDouble;
@@ -57,6 +61,10 @@ import ch.kuramo.javie.api.services.IVideoRenderSupport;
 import ch.kuramo.javie.api.services.IVBOCache.VBOCacheRecord;
 
 import com.google.inject.Inject;
+import com.iabcinc.mapping.voronoi.Point;
+import com.iabcinc.mapping.voronoi.QuadEdge;
+import com.iabcinc.mapping.voronoi.Triangulation;
+import com.iabcinc.mapping.voronoi.VoronoiPolygon;
 
 @Effect(id="ch.kuramo.javie.Shatter", category=Categories.SIMULATION)
 public class Shatter {
@@ -65,7 +73,9 @@ public class Shatter {
 		RECTANGLE,
 		BRICK,
 		HEXAGON,
-		OCTAGON_AND_DIAMOND
+		OCTAGON_AND_DIAMOND,
+		POLYGON_UNIFORMLY,
+		POLYGON_RADIALLY
 	}
 
 	public enum TimeBase {
@@ -290,6 +300,14 @@ public class Shatter {
 					vboIdAndNumVerts = octagonAndDiamond(fragSize, patOrigin, i1, j1, i2, j2);
 					primitiveType = GL2.GL_TRIANGLES;
 					break;
+				case POLYGON_UNIFORMLY:
+					vboIdAndNumVerts = polygon(false, fragSize, patOrigin, i1, j1, i2, j2);
+					primitiveType = GL2.GL_TRIANGLES;
+					break;
+				case POLYGON_RADIALLY:
+					vboIdAndNumVerts = polygon(true, fragSize, patOrigin, i1, j1, i2, j2);
+					primitiveType = GL2.GL_TRIANGLES;
+					break;
 				default:
 					throw new RuntimeException("unknown Pattern: " + pattern);
 			}
@@ -304,7 +322,18 @@ public class Shatter {
 		}
 	}
 
-	private int createVBO(IArray<float[]> data, String token) {
+	private int[] getVBO(String token) {
+		VBOCacheRecord rec = vboCache.get(this);
+		if (rec != null) {
+			Object[] data = (Object[]) rec.data;
+			if (token.equals(data[1])) {
+				return new int[] { rec.vboId, (Integer)data[0] };
+			}
+		}
+		return null;
+	}
+
+	private int[] createVBO(IArray<float[]> data, int numVertices, String token) {
 		GL2 gl = context.getGL().getGL2();
 		int[] vboId = new int[1];
 		try {
@@ -313,11 +342,11 @@ public class Shatter {
 			gl.glBufferData(GL2.GL_ARRAY_BUFFER, data.getLength()*4,
 					FloatBuffer.wrap(data.getArray()), GL2.GL_STATIC_DRAW);
 
-			vboCache.put(this, new VBOCacheRecord(vboId[0], token));
+			vboCache.put(this, new VBOCacheRecord(vboId[0], new Object[] { numVertices, token }));
 
 			int result = vboId[0];
 			vboId = null;
-			return result;
+			return new int[] { result, numVertices };
 
 		} finally {
 			gl.glBindBuffer(GL2.GL_ARRAY_BUFFER, 0);
@@ -327,18 +356,15 @@ public class Shatter {
 
 	private int[] rectangle(Vec2d size, Vec2d origin, int i1, int j1, int i2, int j2) {
 
-		int numFragments = (i2-i1+1)*(j2-j1+1);
-		int numVertices = numFragments*4;		// 頂点数 ＝ 四角形の数 x 四角形1つあたりの頂点数(4)
-
 		String token = String.format("%s/%d,%d/%d,%d/%d,%d,%d,%d",
 				Pattern.RECTANGLE.name(),
 				Double.doubleToLongBits(size.x), Double.doubleToLongBits(size.y),
 				Double.doubleToLongBits(origin.x), Double.doubleToLongBits(origin.y),
 				i1, j1, i2, j2);
 
-		VBOCacheRecord rec = vboCache.get(this);
-		if (rec != null && token.equals(rec.data)) {
-			return new int[] { rec.vboId, numVertices };
+		int[] vboIdAndNumVerts = getVBO(token);
+		if (vboIdAndNumVerts != null) {
+			return vboIdAndNumVerts;
 		}
 
 
@@ -355,6 +381,9 @@ public class Shatter {
 
 		IArray<float[]> data = null;
 		try {
+			int numFragments = (i2-i1+1)*(j2-j1+1);
+			int numVertices = numFragments*4;		// 頂点数 ＝ 四角形の数 x 四角形1つあたりの頂点数(4)
+
 			// 配列の要素数 ＝ 頂点数 x 頂点あたりの座標数(4)
 			// 頂点あたりの座標数は、頂点の座標XとYの2つ、四角形の中心の座標XとYの計4つ
 			data = arrayPools.getFloatArray(numVertices*4);
@@ -374,7 +403,7 @@ public class Shatter {
 				}
 			}
 
-			return new int[] { createVBO(data, token), numVertices };
+			return createVBO(data, numVertices, token);
 
 		} finally {
 			if (data != null) data.release();
@@ -389,18 +418,15 @@ public class Shatter {
 			++j2;
 		}
 
-		int numFragments = (i2-i1+1)*(j2-j1+1);
-		int numVertices = numFragments*6*3;		// 頂点数 ＝ 破片の数 x 破片1つあたりの頂点数(6) x 3(GL_TRIANGLESを使用するため)
-
 		String token = String.format("%s/%d,%d/%d,%d/%d,%d,%d,%d",
 				brick ? Pattern.BRICK.name() : Pattern.HEXAGON.name(),
 				Double.doubleToLongBits(size.x), Double.doubleToLongBits(size.y),
 				Double.doubleToLongBits(origin.x), Double.doubleToLongBits(origin.y),
 				i1, j1, i2, j2);
 
-		VBOCacheRecord rec = vboCache.get(this);
-		if (rec != null && token.equals(rec.data)) {
-			return new int[] { rec.vboId, numVertices };
+		int[] vboIdAndNumVerts = getVBO(token);
+		if (vboIdAndNumVerts != null) {
+			return vboIdAndNumVerts;
 		}
 
 
@@ -438,6 +464,9 @@ public class Shatter {
 
 		IArray<float[]> data = null;
 		try {
+			int numFragments = (i2-i1+1)*(j2-j1+1);
+			int numVertices = numFragments*6*3;		// 頂点数 ＝ 破片の数 x 破片1つあたりの頂点数(6) x 3(GL_TRIANGLESを使用するため)
+
 			// 配列の要素数 ＝ 頂点数 x 頂点あたりの座標数(4)
 			// 頂点あたりの座標数は、頂点の座標XとYの2つ、破片の中心の座標XとYの計4つ
 			data = arrayPools.getFloatArray(numVertices*4);
@@ -469,7 +498,7 @@ public class Shatter {
 				}
 			}
 
-			return new int[] { createVBO(data, token), numVertices };
+			return createVBO(data, numVertices, token);
 
 		} finally {
 			if (data != null) data.release();
@@ -482,18 +511,15 @@ public class Shatter {
 		++i2;
 		++j2;
 
-		int numFragments = (i2-i1+1)*(j2-j1+1);
-		int numVertices = numFragments*(8+4)*3;		// 頂点数 ＝ 破片の数 x 破片1つあたりの頂点数(8および4) x 3(GL_TRIANGLESを使用するため)
-
 		String token = String.format("%s/%d,%d/%d,%d/%d,%d,%d,%d",
 				Pattern.OCTAGON_AND_DIAMOND.name(),
 				Double.doubleToLongBits(size.x), Double.doubleToLongBits(size.y),
 				Double.doubleToLongBits(origin.x), Double.doubleToLongBits(origin.y),
 				i1, j1, i2, j2);
 
-		VBOCacheRecord rec = vboCache.get(this);
-		if (rec != null && token.equals(rec.data)) {
-			return new int[] { rec.vboId, numVertices };
+		int[] vboIdAndNumVerts = getVBO(token);
+		if (vboIdAndNumVerts != null) {
+			return vboIdAndNumVerts;
 		}
 
 
@@ -528,6 +554,9 @@ public class Shatter {
 
 		IArray<float[]> data = null;
 		try {
+			int numFragments = (i2-i1+1)*(j2-j1+1);
+			int numVertices = numFragments*(8+4)*3;		// 頂点数 ＝ 破片の数 x 破片1つあたりの頂点数(8および4) x 3(GL_TRIANGLESを使用するため)
+
 			// 配列の要素数 ＝ 頂点数 x 頂点あたりの座標数(4)
 			// 頂点あたりの座標数は、頂点の座標XとYの2つ、破片の中心の座標XとYの計4つ
 			data = arrayPools.getFloatArray(numVertices*4);
@@ -580,7 +609,139 @@ public class Shatter {
 				}
 			}
 
-			return new int[] { createVBO(data, token), numVertices };
+			return createVBO(data, numVertices, token);
+
+		} finally {
+			if (data != null) data.release();
+		}
+	}
+
+	private int[] polygon(boolean radially, Vec2d size, Vec2d origin, int i1, int j1, int i2, int j2) {
+
+		String token = String.format("%s/%d,%d/%d,%d/%d,%d,%d,%d",
+				radially ? Pattern.POLYGON_RADIALLY.name() : Pattern.POLYGON_UNIFORMLY.name(),
+				Double.doubleToLongBits(size.x), Double.doubleToLongBits(size.y),
+				Double.doubleToLongBits(origin.x), Double.doubleToLongBits(origin.y),
+				i1, j1, i2, j2);
+
+		int[] vboIdAndNumVerts = getVBO(token);
+		if (vboIdAndNumVerts != null) {
+			return vboIdAndNumVerts;
+		}
+
+
+		Triangulation tri = new Triangulation(
+				new Point(origin.x+size.x*(i1-3), origin.y+size.y*(j1-3)),
+				new Point(origin.x+size.x*(i2+3), origin.y+size.y*(j2+3)));
+
+		Random rand = new Random(context.getEffectName().hashCode());
+
+		if (radially) {
+			int n = (i2-i1+1) * (j2-j1+1);
+			double radius = Math.max(size.x*(i2-i1), size.y*(j2-j1));
+			double a = 0, b = 15, c = 0;
+			for (int i = 0; i < n; ++i) {
+				a += 2 * Math.PI / b;
+				double k = Math.floor(a / (2*Math.PI)) + 0.5;
+				double t = k * b / n;
+				double r = t * t * radius * (1+rand.nextGaussian()/10);
+				double x = origin.x + r*Math.cos(a);
+				double y = origin.y + r*Math.sin(a);
+				tri.insertSite(x, y);
+				if ((c += 1/b) >= 1) { ++b; c = 0; }
+			}
+		} else {
+			for (int j = j1; j <= j2; ++j) {
+				for (int i = i1; i <= i2; ++i) {
+					double x = origin.x + size.x*(i+rand.nextDouble()*2-1);
+					double y = origin.y + size.y*(j+rand.nextDouble()*2-1);
+					tri.insertSite(x, y);
+				}
+			}
+		}
+
+		for (int i = i1-1, n = i2+1; i <= n; ++i) {
+			double x = origin.x + size.x*i;
+			tri.insertSite(x, origin.y + size.y*(j1-0.5-rand.nextDouble()));
+			tri.insertSite(x, origin.y + size.y*(j1-0.5-rand.nextDouble()));
+			tri.insertSite(x, origin.y + size.y*(j2+0.5+rand.nextDouble()));
+			tri.insertSite(x, origin.y + size.y*(j2+0.5+rand.nextDouble()));
+		}
+		for (int j = j1-1, n = j2+1; j <= n; ++j) {
+			double y = origin.y + size.y*j;
+			tri.insertSite(origin.x + size.x*(i1-0.5-rand.nextDouble()), y);
+			tri.insertSite(origin.x + size.x*(i1-0.5-rand.nextDouble()), y);
+			tri.insertSite(origin.x + size.x*(i2+0.5+rand.nextDouble()), y);
+			tri.insertSite(origin.x + size.x*(i2+0.5+rand.nextDouble()), y);
+		}
+
+		List<VoronoiPolygon> polygons = tri.getVoronoiPolygons();
+
+		int numVertices = 0;
+		for (VoronoiPolygon p : polygons) {
+			numVertices += p.edges().size() - 2;
+		}
+		numVertices *= 3;
+
+		IArray<float[]> data = null;
+		try {
+			data = arrayPools.getFloatArray(numVertices*4);
+			float[] array = data.getArray();
+
+			int k = 0;
+			for (VoronoiPolygon p : polygons) {
+				Iterator<QuadEdge> it = p.edges().iterator();
+				if (!it.hasNext()) continue;
+
+				Point p0 = it.next().getOrg();
+
+				double gx = 0, gy = 0, ssum = 0;
+				while (it.hasNext()) {
+					QuadEdge qe = it.next();
+					if (!it.hasNext()) break;	// 最後の辺は処理の必要が無いので。
+
+					Point p1 = qe.getOrg();
+					Point p2 = qe.getDest();
+
+					Vector3d cross = new Vector3d();
+					cross.cross(new Vector3d(p1.getX(), p1.getY(), 0),
+								new Vector3d(p2.getX(), p2.getY(), 0));
+					double s = cross.length() / 2;
+
+					gx += s * (p0.getX() + p1.getX() + p2.getX()) / 3;
+					gy += s * (p0.getY() + p1.getY() + p2.getY()) / 3;
+					ssum += s;
+				}
+				gx /= ssum;
+				gy /= ssum;
+
+				it = p.edges().iterator();
+				it.next();
+				while (it.hasNext()) {
+					QuadEdge qe = it.next();
+					if (!it.hasNext()) break;
+
+					Point p1 = qe.getOrg();
+					Point p2 = qe.getDest();
+
+					array[k++] = (float)(p0.getX() - gx);
+					array[k++] = (float)(p0.getY() - gy);
+					array[k++] = (float)gx;
+					array[k++] = (float)gy;
+
+					array[k++] = (float)(p1.getX() - gx);
+					array[k++] = (float)(p1.getY() - gy);
+					array[k++] = (float)gx;
+					array[k++] = (float)gy;
+
+					array[k++] = (float)(p2.getX() - gx);
+					array[k++] = (float)(p2.getY() - gy);
+					array[k++] = (float)gx;
+					array[k++] = (float)gy;
+				}
+			}
+
+			return createVBO(data, numVertices, token);
 
 		} finally {
 			if (data != null) data.release();
