@@ -23,7 +23,6 @@
 
 package ch.kuramo.javie.effects.transition;
 
-import java.nio.FloatBuffer;
 import java.util.HashSet;
 import java.util.Set;
 
@@ -37,6 +36,7 @@ import ch.kuramo.javie.api.IShaderProgram;
 import ch.kuramo.javie.api.IVideoBuffer;
 import ch.kuramo.javie.api.VideoBounds;
 import ch.kuramo.javie.api.IVideoBuffer.TextureFilter;
+import ch.kuramo.javie.api.IVideoBuffer.TextureWrapMode;
 import ch.kuramo.javie.api.annotations.Effect;
 import ch.kuramo.javie.api.annotations.Property;
 import ch.kuramo.javie.api.annotations.ShaderSource;
@@ -51,38 +51,26 @@ import com.google.inject.Inject;
 public class GradientWipe {
 
 	@ShaderSource
-	public static final String[] GRADIENT_WIPE_NORMAL = createShaderSource(false, false);
+	public static final String[] GRADIENT_WIPE_NORMAL = createShaderSource(false);
 
 	@ShaderSource
-	public static final String[] GRADIENT_WIPE_NORMAL_TILE = createShaderSource(false, true);
-
-	@ShaderSource
-	public static final String[] GRADIENT_WIPE_INVERT = createShaderSource(true, false);
-
-	@ShaderSource
-	public static final String[] GRADIENT_WIPE_INVERT_TILE = createShaderSource(true, true);
+	public static final String[] GRADIENT_WIPE_INVERT = createShaderSource(true);
 
 
-	private static String[] createShaderSource(boolean invert, boolean tile) {
+	private static String[] createShaderSource(boolean invert) {
 		return new String[] {
-				"uniform sampler2DRect srcTex;",
-				"uniform sampler2DRect grdTex;",
+				"uniform sampler2D srcTex;",
+				"uniform sampler2D grdTex;",
 				"uniform float min;",
 				"uniform float max;",
-
-		 tile ? "uniform vec2 size;"
-			  : "",
-
 				"",
 				"const vec3 yvec = vec3(0.299, 0.587, 0.114);",
 				"",
 				"void main(void)",
 				"{",
-				"	vec4 src = texture2DRect(srcTex, gl_TexCoord[0].st);",
+				"	vec4 src = texture2D(srcTex, gl_TexCoord[0].st);",
+				"	vec4 grd = texture2D(grdTex, gl_TexCoord[1].st);",
 
-				"	vec2 grdCoord = gl_TexCoord[1].st;",
-		 tile ? "	vec4 grd = texture2DRect(grdTex, grdCoord - floor(grdCoord/size)*size);"
-			  : "	vec4 grd = texture2DRect(grdTex, grdCoord);",
 	   invert ? "	float y = 1.0 - dot(grd.rgb, yvec);"
 			  : "	float y = dot(grd.rgb, yvec);",
 
@@ -118,20 +106,14 @@ public class GradientWipe {
 
 	private final IShaderProgram normalProgram;
 
-	private final IShaderProgram normalTileProgram;
-
 	private final IShaderProgram invertProgram;
 
-	private final IShaderProgram invertTileProgram;
-
 	@Inject
 	public GradientWipe(IVideoEffectContext context, IVideoRenderSupport support, IShaderRegistry shaders) {
 		this.context = context;
 		this.support = support;
 		this.normalProgram = shaders.getProgram(GradientWipe.class, "GRADIENT_WIPE_NORMAL");
-		this.normalTileProgram = shaders.getProgram(GradientWipe.class, "GRADIENT_WIPE_NORMAL_TILE");
 		this.invertProgram = shaders.getProgram(GradientWipe.class, "GRADIENT_WIPE_INVERT");
-		this.invertTileProgram = shaders.getProgram(GradientWipe.class, "GRADIENT_WIPE_INVERT_TILE");
 	}
 
 	public IVideoBuffer doVideoEffect() {
@@ -160,7 +142,6 @@ public class GradientWipe {
 		try {
 			double softness = context.value(transitionSoftness)/100;
 			GradientPlacement placement = context.value(gradientPlacement);
-			boolean tile = (placement == GradientPlacement.TILE);
 			boolean invert = context.value(invertGradient);
 	
 			double max = (1 + softness) * completion;
@@ -177,43 +158,41 @@ public class GradientWipe {
 
 
 			final double[][][] texCoords = new double[2][][];
+			texCoords[0] = new double[][] { {0, 0}, {1, 0}, {1, 1}, {0, 1} };
 
 			int w = bounds.width;
 			int h = bounds.height;
-			texCoords[0] = new double[][] { {0, 0}, {w, 0}, {w, h}, {0, h} };
+			int gw = gradBounds.width;
+			int gh = gradBounds.height;
 
 			switch (placement) {
 				case CENTER: {
-					float s = (gradBounds.width - bounds.width) / 2f;
-					float t = (gradBounds.height - bounds.height) / 2f;
-					texCoords[1] = new double[][] { {s, t}, {s+w, t}, {s+w, t+h}, {s, t+h} };
+					double s = (gw-w)/2.0, t = (gh-h)/2.0;
+					double s0 = s/gw, t0 = t/gh, s1 = (s+w)/gw, t1 = (t+h)/gh;
+					texCoords[1] = new double[][] { {s0, t0}, {s1, t0}, {s1, t1}, {s0, t1} };
 					break;
 				}
 
-				case STRETCH: {
-					int gw = gradBounds.width;
-					int gh = gradBounds.height;
-					texCoords[1] = new double[][] { {0, 0}, {gw, 0}, {gw, gh}, {0, gh} };
+				case STRETCH:
+					texCoords[1] = new double[][] { {0, 0}, {1, 0}, {1, 1}, {0, 1} };
+					gradient.setTextureFilter(TextureFilter.LINEAR);	// 終わったら削除してしまうので、元に戻す必要はない。
+					break;
+
+				case TILE: {
+					double s = (double)w/gw, t = (double)h/gh;
+					texCoords[1] = new double[][] { {0, 0}, {s, 0}, {s, t}, {0, t} };
+					gradient.setTextureWrapMode(TextureWrapMode.REPEAT);	// 終わったら削除してしまうので、元に戻す必要はない。
 					break;
 				}
-
-				default:
-					texCoords[1] = new double[][] { {0, 0}, {w, 0}, {w, h}, {0, h} };
-					break;
 			}
 
-			IShaderProgram program = tile ? (invert ? invertTileProgram : normalTileProgram)
-										  : (invert ? invertProgram : normalProgram);
+			IShaderProgram program = invert ? invertProgram : normalProgram;
 
 			Set<GLUniformData> uniforms = new HashSet<GLUniformData>();
 			uniforms.add(new GLUniformData("srcTex", 0));
 			uniforms.add(new GLUniformData("grdTex", 1));
 			uniforms.add(new GLUniformData("min", (float)min));
 			uniforms.add(new GLUniformData("max", (float)max));
-			if (tile) {
-				uniforms.add(new GLUniformData("size", 2, FloatBuffer.wrap(
-						new float[] { gradBounds.width, gradBounds.height })));
-			}
 
 			Runnable operation = new Runnable() {
 				public void run() {
@@ -222,11 +201,6 @@ public class GradientWipe {
 				}
 			};
 
-			if (placement == GradientPlacement.STRETCH) {
-				// 終わったら削除してしまうので、元に戻す必要はない。
-				gradient.setTextureFilter(TextureFilter.LINEAR);
-			}
-
 			return support.useShaderProgram(program, uniforms, operation, 0, null, input, gradient);
 
 		} finally {
